#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with git
%define panel_version 4.14.0
%define plugin wavelan
Name:           xfce4-%{plugin}-plugin
Version:        0.6.3
Release:        1.7
Summary:        WLAN Monitoring Plugin for the Xfce Panel
License:        BSD-2-Clause
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-wavelan-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/0.6/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= %{panel_version}
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The WaveLAN plugin can monitor a wireless LAN interface and display signal
state, quality and the network name (SSID).

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print
rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS README.md THANKS
%license COPYING
%{_libdir}/xfce4/panel/plugins/libwavelan.so
%{_datadir}/xfce4/panel/plugins/wavelan.desktop

%files lang -f %{name}.lang

%changelog
* Wed Jun 22 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.6.3
  * Fix intltool lock file bug in make distcheck
  * Fix read_config memory leaks
  * Add option to execute command on icon click
    (gxo#panel-plugins/xfce4-wavelan-plugin!9)
  * Add option to hide signal bar
    (gxo#panel-plugins/xfce4-wavelan-plugin!8)
  * Prefer symbolic icons and fix icon color
    (gxo#panel-plugins/xfce4-wavelan-plugin!7)
  * Icon now shows signal strength
    (gxo#panel-plugins/xfce4-wavelan-plugin!5)
  * remove bogus close function
  * autoconf: Some updates
  * Translation Updates
* Fri Dec 25 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.6.2
  * Fix build with panel 4.15
  * Fix ISO C90 forbids mixed declarations and code
  * Update configure.ac.in syntax and enable debug when building from git
  * Create README.md. Update configure.ac.in
  * Add basic GitLab pipeline
  * Update .gitignore, fix configure scripts
  * Update URLs from goodies.x.o to docs.x.o (bxo#16181)
  * Make build less verbose
  * s/http/https
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources and url in spec file
* Wed Aug 14 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.6.1
  * Preferences: Improve spacing (bxo#14679)
  * fix "Suspicious condition (assignment + comparison)" warnings by
    moving parenthesis (bxo#14632)
  * fix build under and usage under FreeBSD
  * refactor progressbar styling (bxo#12942)
  * use a singleton for GtkCssProvider, should leak less memory
  * translation updates
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
- Move COPYING under %%license macro
* Sun Nov 27 2016 seife+obs@b1-systems.com
- update to version 0.6.0
  - port to gtk+3/libxfce4ui-2/libxfce4panel-2.0
  - translation updates
- do not package ChangeLog; NEWS is good enough
* Wed Mar  4 2015 gber@opensuse.org
- update to version 0.5.12
  - add strings to translation
  - use GtkComboBoxText instead of GtkCombo
  - use check buttons with mnemonic for hot keys
  - use getifaddrs() instead of popen ("/sbin/ifconfig -a")
    (bxo#10822)
  - remove check for glib 2.14, was released 7 years ago..
  - make this compile with -Wall -Werror (declarations after
    statement)
  - updated translations
* Sun Jul  1 2012 gber@opensuse.org
- update to version 0.5.11
  - better compliance with panel plugin HIG
  - fix transparency and put event box above its children
* Fri Apr 20 2012 gber@opensuse.org
- corrected license
- corrected documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Sat Apr 14 2012 gber@opensuse.org
- update to version 0.5.10
  - add an option to hide the icon for small screen/panels
  - translation updates
* Tue Apr 10 2012 gber@opensuse.org
- update to version 0.5.8
  - build the plugin as a module loadable by Xfce4's panel wrapper
  - add an about dialog
  - fix properties dialog look
* Tue Apr  3 2012 gber@opensuse.org
- update to version 0.5.7
  - port to libxfce4ui
  - adapt to panel 4.9 and newer
  - fix transparency and bar color
  - explicitely link against libm
- dropped obsolete
  xfce4-panel-plugin-wavelan-0.5.6-fix-transparency-and-bar-color.patch,
  xfce4-wavelan-plugin-0.5.6-fix-libm-underlinking.patch
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Wed Sep 21 2011 gber@opensuse.org
- added xfce4-wavelan-plugin-0.5.6-fix-libm-underlinking.patch in
  order to explicitly link against libm
- added
  xfce4-panel-plugin-wavelan-0.5.6-fix-transparency-and-bar-color.patch
  in order to fix transparency and bar color (backported from
  upstream git)
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
